---
name: 🛠️ Missing Reclass feature
about: Report a missing Reclass feature 💡
labels: enhancement
---

## Missing feature
<!--
Please describe the Reclass feature that's missing. If possible, please link
to the Reclass documentation (or the Kapitan Reclass extensions documentation)
that describes the feature.
-->

## Reclass settings
<!--
Please provide your reclass settings. If you're using Kapitan, please provide
the full `reclass-config.yml` that you're using.
-->

## Example inventory
<!--
If feasible, please provide a minimal example inventory that makes use of the
missing feature. By doing so, you're making it much easier for us to implement
and test the missing feature.

You can share an example inventory as follows:

1. Setup the example inventory structure (including `reclass-config.yml` if
   necessary) in a temporary directory
2. Verify that the example inventory demonstrates the buggy behavior
3. Run `tar cj * | base64 -w 0` in the temporary directory
   On macOS, you'll need to leave out `-w 0`.
4. Copy the resulting base64 string into a code block in this section
5. If you've changed the `tar` command, please provide your version
-->
